function out1=DQMOM_Solver(t,alpha)
% IGEM INSA-UPS Toulouse 2022 - DAISY team
% link to wiki : https://2022.igem.wiki/toulouse-insa-ups/index.html
% link to model : https://2022.igem.wiki/toulouse-insa-ups/model
% Main script of Agregation Dynamics, MATLAB
% Adapted from a model used on : 
% FRANCES C, LINE A. Comminution Process Modeling Based on the Monovariate
% and Bivariate Direct Quadrature Method of Moments AIChE J. 2014 DOI:10.1002/aic.14358
% DQMOM Bivariate - Case solving of homogenous system with two properties
% for biologic phase.
% The function DQMOM_Solver solves the linear system of equation
% A*alpha=PBE_Model
% alpha : column vector with weights then product of each abscissas with
% the corresponding weight for each propertie. Its dimesnion is (Ns+1)*N
% with Ns the number of properties and N the number of nodes
% t : timepoint
% dim(alpha)=6 if N=2
% dim(alpha)=9 if N=3

global N vK vL k1 k2 

% L1 represents the amount of A on an aggregate
% L2 represents the amount of D on an aggregate

% Abscissa expression for each considered property (A and D)
alpha;
L1=zeros(N,1);
L2=zeros(N,1);
for i=1:N
    L1(i)=alpha(N+i)/alpha(i);
    L2(i)=alpha(2*N+i)/alpha(i);
end

% Expression of the matrix A, with A=[A1,A2,A3]
out1=zeros(3*N,1);
A1=zeros(3*N,N);
A2=zeros(3*N,N);
A3=zeros(3*N,N);
A=zeros(3*N,3*N);

for j=1:N
    for i1=1:3
        for i2=1:N
            k=N*(i1-1)+i2;
            k1=vK(k);
            k2=vL(k);
            A1(k,j)=(1-k1-k2)*L1(j)^k1*L2(j)^k2;
            A2(k,j)=k1*L1(j)^(k1-1)*L2(j)^k2;
            A3(k,j)=k2*L1(j)^k1*L2(j)^(k2-1);
        end
    end
end

A=[A1,A2,A3];

% Right hand of the linear equation system, call function PBE_Model
dsimpl=zeros(3*N,1);
dsimpl=PBE_Model_2(L1,L2,alpha);
% Solving of the linear equation system - affectation of alpha vector

% out1=A\dsimpl;
out1=inv(A)*dsimpl;
