function out23=PBE_Model_1(L1,L2,alpha)
% IGEM INSA-UPS Toulouse 2022 - DAISY team
% link to wiki : https://2022.igem.wiki/toulouse-insa-ups/index.html
% link to model : https://2022.igem.wiki/toulouse-insa-ups/model
% Main script of Agregation Dynamics, MATLAB
% Adapted from a model used on : 
% FRANCES C, LINE A. Comminution Process Modeling Based on the Monovariate
% and Bivariate Direct Quadrature Method of Moments AIChE J. 2014 DOI:10.1002/aic.14358
% DQMOM Bivariate - Case solving of homogenous system with two properties
% for biologic phase.
% Function containing the PBE equation.
% L1 : Values of the first property
% L2 : Values of the second property
% alpha : column vector with weights then product of each abscissas with
% the corresponding weight for each propertie. Its dimesnion is (Ns+1)*N
% with Ns the number of properties and N the number of nodes

global N vK vL k1 k2
global G K_beta K_gamma


out23=zeros(3*N,1);
for i1=1:3
    for i2=1:N
        k=N*(i1-1)+i2;
        k1=vK(k);
        k2=vL(k);
        out23(k)=0; %zeros(3*N,1);
        for j1 = 1:N
            for j2 = 1:N
                beta = K_beta*G*(L1(j1)+L1(j2)+L2(j1)+L2(j2))*(1/(L1(j1)+L1(j2))+1/(L2(j1)+L2(j2)))*K_gamma*(L1(j1)*L2(j2)+L1(j2)*L2(j1))/(L1(j1)+L1(j2))/(L2(j1)+L2(j2));
                out23(k)=out23(k)+1/2*alpha(j1)*alpha(j2)*((L1(j1)+L1(j2))^k1*(L2(j1)+L2(j2))^k2-L1(j1)^k1*L2(j1)^k2 - L1(j2)^k1*L2(j2)^k2 )*beta;
            end
        end
    end
end
