% IGEM INSA-UPS Toulouse 2022 - DAISY team
% link to wiki : https://2022.igem.wiki/toulouse-insa-ups/index.html
% link to model : https://2022.igem.wiki/toulouse-insa-ups/model
% Main script of Agregation Dynamics, MATLAB
% Adapted from a model used on :
% FRANCES C, LINE A. Comminution Process Modeling Based on the Monovariate
% and Bivariate Direct Quadrature Method of Moments AIChE J. 2014 DOI:10.1002/aic.14358
% DQMOM Bivariate - Case solving of homogenous system with two properties
% for biologic phase.
% Plotting script for data saved from SimulationX for vizualisation of the
% problem
% Command on main script : save Path/Name alpha0 N T alpha tfin

clear all
close all

% Loading command
load C:\Users\Raphaël\Desktop\Matlab\Modélisation\PBE_Modeling_V3\Results\20220804-4

% Calculations of moments and abscissas
taille=size(alpha);
L1=zeros(taille(1),N);
L2=zeros(taille(1),N);
W=zeros(taille(1),N);
for i=1:N
    L1(:,i)=alpha(:,N+i)./alpha(:,i); % First abscissa
    L2(:,i)=alpha(:,2*N+i)./alpha(:,i); % Second abscissa
    W(:,i)=alpha(:,i); % Weight 
end

m00=zeros(taille(1),1);
m10=zeros(taille(1),1);
m01=zeros(taille(1),1);
m11=zeros(taille(1),1);
m_somme =  zeros(taille(1),1);
for j=1:taille(1)
    for i=1:N
        m00(j)=m00(j)+alpha(j,i);
        m10(j)=m10(j)+alpha(j,i)*L1(j,i);
        m01(j)=m01(j)+alpha(j,i)*L2(j,i);
        m11(j)=m11(j)+alpha(j,i)*L1(j,i)*L2(j,i);
    end
    m_somme(j) = m01(j)+m10(j);
end

% Abscissas curves for each properties (number of A, D, and percentage of A
% and D on each agregate)
if N == 2
    figure(1) % N = 2
    hold on
    plot(T,L1(:,1),'<k',T,L1(:,2),'>k')
    title('Variation of number of strain A on aggregates')
    legend('A1','A2')
    xlabel('Temps(sec)')
    ylabel('Abscisses - A')
    hold off
    figure(2) %
    hold on
    plot(T,L2(:,1),'<r',T,L2(:,2),'>r')
    title('Variation of number of strain B on aggregates')
    legend('D1','D2')
    xlabel('Temps(sec)'),ylabel('Abscisses - D')
    hold off
    figure(3) %
    hold on
    title('Evolution of the proportion of aggregate')
    semilogy(T,alpha(:,1),'<k',T,alpha(:,2),'>k')
    legend('w1 (% of A)','w2 (% of D)')
    xlabel('Temps(sec)'),ylabel('Poids ')
    hold off
else   % N = 3
    figure(1)
    hold on
    plot(T,L1(:,1),'<k',T,L1(:,2),'ok',T,L1(:,3),'>k')
    title('Variation of the number of strain A on aggregates')
    legend('A1','A2','A3')
    xlabel('Temps(sec)'),ylabel('Abscisses - A')
    hold off
    figure(2)
    hold on
    plot(T,L2(:,1),'<r',T,L2(:,2),'or',T,L2(:,3),'>r')
    title('Variation of number of strain B on aggregates')
    legend('D1','D2','D3')
    xlabel('Temps(sec)'),ylabel('Abscisses - D')
    hold off
    figure(3)
    hold on
    plot(T,alpha(:,1),'<k',T,alpha(:,2),'ok',T,alpha(:,3),'>k')
    title('Evolution of percentage of A and D on aggregates')
    legend('w1','w2','w3')
    xlabel('Temps(sec)'),ylabel('Poids')
    hold off
end

% Plotting of moments and control of mass conservation.
% Plotting variation of each moment
figure(4)
hold on
plot(T,m00,'+',T,m10,'o',T,m01,'*',T,m11)
title('Graph of variation of moments')
legend('m00 DQMOM','m10 DQMOM','m01 DQMOM','m11 DQMOM')
xlabel('Temps(sec)'),ylabel('moments')
hold off
% Plotting variation of each moment with log scale
figure(5)
semilogy(T,m00,'+',T,m10,'o',T,m01,'*',T,m11)
title('Graph of variation of moments with log scale')
legend('m00 DQMOM','m10 DQMOM','m01 DQMOM','m11 DQMOM')
xlabel('Temps(sec)'),ylabel('moments')
% Control of mass balance on the system (d(m10+m01)/dt ~0)
figure(6)
hold on
plot(T,m_somme,'+')
title('Evolution of mass balance on the system')
xlabel('Temps(sec)'), ylabel('moments')
hold off


% 3D plots

if N == 2
    % Choice of a common view for each 3D plot, invocate it for each plot with
    % view(Vue)
    Vue=[18 12];


    % Vizualisation of weights/abscissas on initial state N=2
    h=figure;
    hold on
    plot3([L1(1,1),L1(1,1)],[L2(1,1),L2(1,1)],[0,W(1,1)],'b-',[L1(1,2),L1(1,2)],[L2(1,2),L2(1,2)],[0,W(1,2)],'k-')
    axis([0 10 0 10 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution at t=0')
    view(Vue)
    grid ON
    hold off



    % Vizualisation of weights/abscissas on an intermediary state N=2
    h=figure;
    i=length(W)/2;
    hold on
    axis([0 10 0 10 0 1])
    plot3([L1(i,1),L1(i,1)],[L2(i,1),L2(i,1)],[0,W(i,1)],'b-',[L1(i,2),L1(i,2)],[L2(i,2),L2(i,2)],[0,W(i,2)],'k-')
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Intermediary distribution t=t_e_n_d /2')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas on end state N=2
    h=figure;
    hold on
    plot3([L1(end,1),L1(end,1)],[L2(end,1),L2(end,1)],[0,W(end,1)],'b-',[L1(end,2),L1(end,2)],[L2(end,2),L2(end,2)],[0,W(end,2)],'k-')
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution at t=t_e_n_d')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas on initial, intermediary and final state N=2
    h=figure;
    hold on
    i=length(W)/2;
    Fini = plot3([L1(1,1),L1(1,1)],[L2(1,1),L2(1,1)],[0,W(1,1)],'r-',[L1(1,2),L1(1,2)],[L2(1,2),L2(1,2)],[0,W(1,2)],'r-') ;
    Fmid = plot3([L1(i,1),L1(i,1)],[L2(i,1),L2(i,1)],[0,W(i,1)],'g-',[L1(i,2),L1(i,2)],[L2(i,2),L2(i,2)],[0,W(i,2)],'g-') ;
    Fend = plot3([L1(end,1),L1(end,1)],[L2(end,1),L2(end,1)],[0,W(end,1)],'b-',[L1(end,2),L1(end,2)],[L2(end,2),L2(end,2)],[0,W(end,2)],'b-') ;
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1) Fmid(1) Fend(1)],'Initial state','Intermediary state','Final state')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas along the time N=2
    h=figure;
    hold on
    Fini = plot3(L1(:,1),L2(:,1),W(:,1),'r-',L1(:,2),L2(:,2),W(:,2),'b-') ;
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1),Fini(2)],'1st node','2nd node')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas along the time N=2 with peaks N=2
    h=figure;
    hold on
    for j=1:length(L1)
        Fini = plot3([L1(j,1),L1(j,1)],[L2(j,1),L2(j,1)],[0,W(j,1)],'r-',[L1(j,2),L1(j,2)],[L2(j,2),L2(j,2)],[0,W(j,2)],'b-') ;
    end
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1),Fini(2)],'1st node','2nd node')
    view(Vue)
    grid ON
    hold off


else % N==3
    % Choice of a common view for each 3D plot, invocate it for each plot with
    % view(Vue)
    Vue=[118 14];

    % Vizualisation of weights/abscissas on initial state N=3
    h=figure;
    hold on
    plot3([L1(1,1),L1(1,1)],[L2(1,1),L2(1,1)],[0,W(1,1)],'b-',[L1(1,2),L1(1,2)],[L2(1,2),L2(1,2)],[0,W(1,2)],'k-',[L1(1,3),L1(1,3)],[L2(1,3),L2(1,3)],[0,W(1,3)],'r-')
    axis([0 (max(max(L1(1,:)))+1) 0 (max(max(L2(1,:)))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution at t=0')
    view(Vue)
    grid ON
    hold off



    % Vizualisation of weights/abscissas on intermediary state N=3
    h=figure;
    i=length(W)/2;
    hold on
    axis([0 (max(max(L1(i,:)))+1) 0 (max(max(L2(i,:)))+1) 0 1])
    plot3([L1(i,1),L1(i,1)],[L2(i,1),L2(i,1)],[0,W(i,1)],'b-',[L1(i,2),L1(i,2)],[L2(i,2),L2(i,2)],[0,W(i,2)],'k-',[L1(i,3),L1(i,3)],[L2(i,3),L2(i,3)],[0,W(i,3)],'r-')
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Intermediary distribution t=t_e_n_d /2')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas on final state N=3
    h=figure;
    hold on
    plot3([L1(end,1),L1(end,1)],[L2(end,1),L2(end,1)],[0,W(end,1)],'b-',[L1(end,2),L1(end,2)],[L2(end,2),L2(end,2)],[0,W(end,2)],'k-',[L1(end,3),L1(end,3)],[L2(end,3),L2(end,3)],[0,W(end,3)],'r-')
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution at t=t_e_n_d')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas on initial, intermediary and final
    % state N=3
    h=figure;
    hold on
    i=length(W)/2;
    Fini = plot3([L1(1,1),L1(1,1)],[L2(1,1),L2(1,1)],[0,W(1,1)],'b-',[L1(1,2),L1(1,2)],[L2(1,2),L2(1,2)],[0,W(1,2)],'k-',[L1(1,3),L1(1,3)],[L2(1,3),L2(1,3)],[0,W(1,3)],'k-');
    Fmid = plot3([L1(i,1),L1(i,1)],[L2(i,1),L2(i,1)],[0,W(i,1)],'g-',[L1(i,2),L1(i,2)],[L2(i,2),L2(i,2)],[0,W(i,2)],'g-',[L1(i,3),L1(i,3)],[L2(i,3),L2(i,3)],[0,W(i,3)],'g-');
    Fend = plot3([L1(end,1),L1(end,1)],[L2(end,1),L2(end,1)],[0,W(end,1)],'b-',[L1(end,2),L1(end,2)],[L2(end,2),L2(end,2)],[0,W(end,2)],'b-',[L1(end,3),L1(end,3)],[L2(end,3),L2(end,3)],[0,W(end,3)],'b-');
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1) Fmid(1) Fend(1)],'Initial state','Intermediary state','Final state')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas along the time N=3
    h=figure;
    hold on
    Fini = plot3(L1(:,1),L2(:,1),W(:,1),'r-',L1(:,2),L2(:,2),W(:,2),'b-',L1(:,3),L2(:,3),W(:,3),'g-') ;
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1),Fini(2),Fini(3)],'1st node','2nd node','3rd node')
    view(Vue)
    grid ON
    hold off


    % Vizualisation of weights/abscissas along the time N=3
    h=figure;
    hold on
    for j=1:length(L1)
        Fini = plot3([L1(j,1),L1(j,1)],[L2(j,1),L2(j,1)],[0,W(j,1)],'r-',[L1(j,2),L1(j,2)],[L2(j,2),L2(j,2)],[0,W(j,2)],'b-',[L1(j,3),L1(j,3)],[L2(j,3),L2(j,3)],[0,W(j,3)],'g-') ;
    end
    axis([0 (max(max(L1))+1) 0 (max(max(L2))+1) 0 1])
    xlabel('L1'), ylabel('L2'), zlabel('W '), title('Distribution along the time')
    legend([Fini(1),Fini(2),Fini(3)],'1st node','2nd node','3rd node')
    view(Vue)
    grid ON
    hold off

end
