##########
# README #
##########


#IGEM team Toulouse_INSA_UPS 2022 
#DAISY
#link to wiki : https://2022.igem.wiki/toulouse-insa-ups/index.html
#link to model : https://2022.igem.wiki/toulouse-insa-ups/model

# This code run calculations for the model set on the complexation_model.cps to calculate the 
# the interaction potential for an aggregation between DARPin and an allergen with KD known.


##########################
# INITIALIZE ENVIRONMENT #
##########################

# go to code directory (uncomment the following line)

#setwd("~/Downloads/COPASI")

# load libraries and initialize environment

source("set_env.R")


loadModel("model_complexation_v5.simulation_1_arah2.cps")



# definition of the perturbations to simulate

# #   number of steps (50)
 n_step <- 50
# 
# #create a range of A and D concentrations
# 
# #   concentration of A
 initial_concentration_D <- 10**seq(-14, -7, length.out = n_step)
# 
# #   concentration of D
 initial_concentration_A <- 10**seq(-14, -7, length.out = n_step)

# create empty matrix to store simulation results

fluxes <- c("Values[Interaction_potential]")
simulation_results <- array(NA, dim=c(n_step, n_step, length(fluxes)), dimnames=list(initial_concentration_A=NULL, initial_concentration_D=NULL, specie=fluxes))

# run simulations

# for each concentration A
for (k in seq(length(initial_concentration_A))){
  
  # create empty matrix to store simulation results for concentration A (k)
  res <- matrix(NA, nrow=n_step, ncol=length(fluxes), dimnames=list(r=NULL, c=fluxes))
  
  # update concentration A
  setGlobalQuantities(key="initial_concentration_A", initial_value=initial_concentration_A[k])
  
  applyInitialState()
  
  #print("initial concentration A")
  #print(getGlobalQuantities(key="initial_concentration_A")$initial_value)
  
  # for each concentration D
  for (j in seq(length(initial_concentration_D))){
    
    # update concentration D
    setGlobalQuantities(key="initial_concentration_D", initial_value=initial_concentration_D[j])
    applyInitialState()
    
    #print("initial concentration D")
    #print(getGlobalQuantities(key="initial_concentration_D")$initial_value)

    # calculate steady-state fluxes
    res_ss <- runSteadyState()
    
    # save steady-state for k,j
    res[j,] <- unlist(res_ss$global_quantities[res_ss$global_quantities$key %in% fluxes, "value"])
  }
  
  # save steady-state fluxes for concentration k
  simulation_results[k,,] <- res
  
}
#uncomment when you want to export a csv file of the simulation results
#write.csv2(simulation_results, file="simulation_1_arah2.csv")

## uncomment when you want to download the simulation_results matrix

#pdf(file="Simulation_1_arah2.pdf", width = 5, height = 4)

filled.contour(x=log10(initial_concentration_A), y=log10(initial_concentration_D), z = simulation_results[,,1], nlevels = 10,
               xlab="[A-molecules]", ylab="[D-molecules]")

#plot the variation of Interaction_potential for one given D concentration, and a range of A concentrations
plot(x=log10(initial_concentration_A), y=simulation_results[,5,1], xlab= "[A-molecules]", ylab="aggregation potential", type="l")

#dev.off()





